import * as React from 'react';
import { Button, Table, Header, Container } from 'semantic-ui-react';
import { DetailContainer } from '@overflow/commons/react/component/DetailContainer';
import { TargetDetailInfra } from './TargetDetailInfra';
import InfraDetailContainer from '@overflow/infra/react/InfraDetail';
import Infra from '@overflow/infra/api/model/Infra';


export interface StateProps {
  id: string;
  infra: Infra;
}

export interface DispatchProps {
  onRead(id: string): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
}


export class TargetDetail extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
    };
  }

  public componentWillMount(): void {
    this.props.onRead(this.props.id);
  }

  public handleRemoveTarget(): void {
    alert('remove');
  }

  public render(): JSX.Element {
    if (this.props.infra === undefined) {
      return null;
    }
    return (
      <Container fluid>
        <TargetBasicInfo infra={this.props.infra} />
        <br />
        <InfraDetailContainer infra={this.props.infra} />
        <br />
        <Button primary floated={'right'} negative onClick={this.handleRemoveTarget}>Remove</Button>
      </Container>
    );
  }
}


export interface TargetBasicInfoProps {
  infra?: Infra;
}

export interface TargetBasicInfoState {
}

export class TargetBasicInfo extends React.Component<TargetBasicInfoProps, TargetBasicInfoState> {

  constructor(props: TargetBasicInfoProps, context: TargetBasicInfoState) {
    super(props, context);
    this.state = {
    };
  }

  public render(): JSX.Element {
    return (
      <Container fluid>
        <Table celled={false}>
          <Table.Body>
            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Name</Header>
              </Table.Cell>
              <Table.Cell>
                {this.props.infra.target.displayName}
              </Table.Cell>
            </Table.Row>

            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Description</Header>
              </Table.Cell>
              <Table.Cell>
                {this.props.infra.target.description}
              </Table.Cell>
            </Table.Row>

            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Sensor Count</Header>
              </Table.Cell>
              <Table.Cell>
                TODO
              </Table.Cell>
            </Table.Row>

            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Created at</Header>
              </Table.Cell>
              <Table.Cell>
                {this.props.infra.target.createDate}
              </Table.Cell>
            </Table.Row>

            <Table.Row>
              <Table.Cell collapsing>
                <Header size='small'>Type</Header>
              </Table.Cell>
              <Table.Cell>
                {this.props.infra.infraType.name}
              </Table.Cell>
            </Table.Row>
          </Table.Body>
        </Table>
      </Container>
    );
  }
}
