import * as React from 'react';
import { Table, Button, Modal, Input, Header, Container, InputOnChangeData, ButtonProps } from 'semantic-ui-react';
import { TargetDetail } from './TargetDetail';
import Infra from '@overflow/infra/api/model/Infra';
import Probe from '@overflow/probe/api/model/Probe';
import { ListContainer } from '@overflow/commons/react/component/ListContainer';
import { Discovery } from '../../../discovery/react/components/Discovery';

export interface StateProps {
  probeId: string;
  infraList: Infra[];
}

export interface DispatchProps {
  onReadAllByProbe(probe: Probe): void;
  onTargetSelection(id: string): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: Infra;
  openAddTarget: boolean;
}

export class TargetList extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      selected: null,
      openAddTarget: false,
    };
  }

  public componentWillMount(): void {
    let probe: Probe = {
      id: Number(1),
    };
    this.props.onReadAllByProbe(probe);
  }

  public handleSelect(selectedTarget: any): void {

    this.setState({
      selected: selectedTarget,
    });

    this.props.onTargetSelection(selectedTarget.id);
  }


  public handleAddTarget(event: React.MouseEvent<HTMLButtonElement>, data: ButtonProps): void {
    this.setState({
      openAddTarget: true,
    });
  }

  public handleSearch(result: Infra[]): void {
    // this.setState({
    //   list: result,
    // });
  }

  public handleFilter(filterStr: string): void {
    // if (filterStr === null) {
    //   this.setState({
    //     list: this.data,
    //   });
    //   return;
    // }
    // let founds = new Array();
    // for (let probe of this.data) {
    //   if (probe.metaProbeStatus.name.indexOf(filterStr) !== -1) {
    //     founds.push(probe);
    //   }
    // }
    // this.setState({
    //   list: founds,
    // });
  }

  public render(): JSX.Element {
    if(this.props.infraList === undefined) {
      return null;
    }
    let targetList =
      <Container fluid>
        <Button content='Discovery' icon='search' labelPosition='left' floated='right' positive onClick={this.handleAddTarget.bind(this)} />
        <br /><br />
        <Table celled selectable striped>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>No</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Type</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Name</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'} collapsing>Sensor Count</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Created at</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.props.infraList.map((infra: Infra, index: number) => (
              <Table.Row key={index} onClick={this.handleSelect.bind(this, infra)}>
                <Table.Cell textAlign={'center'}>{index + 1}</Table.Cell>
                 <Table.Cell textAlign={'center'}>{infra.infraType.name}</Table.Cell>
                <Table.Cell textAlign={'center'}>{infra.target.displayName}</Table.Cell>
                <Table.Cell>TODO</Table.Cell>
                <Table.Cell>{infra.target.createDate}</Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
        <Modal
          open={this.state.openAddTarget}
        >
          {/*<Modal.Header>*/}
          {/*Adding a Target*/}
          {/*</Modal.Header>*/}
          <Modal.Content>
            <Discovery />
          </Modal.Content>
          <Modal.Actions>
            <Button onClick={() => this.setState({ openAddTarget: false })}>Cancel</Button>
            <Button primary >Done</Button>
          </Modal.Actions>
        </Modal>
      </Container>;
    return (
      <ListContainer
        contents={targetList}
        data={this.props.infraList}
        onSearch={this.handleSearch.bind(this)}
        filter={null}
      />
    );
  }

  private handleSelectedTarget = (infra: Infra): void => {
    console.log('handleSelectedTarget ');
    this.setState({ selected: infra });

    this.props.onTargetSelection(String(infra.id));
  }
}

